pub enum Shutdown {
Read,
Write,
Both,
}Possible values which can be passed to the shutdown method of TcpStream
and UdpSocket.
Variants
Read | Indicates that the reading portion of this stream/socket should be shut
down. All currently blocked and future reads will return Ok(0).
|
Write | Indicates that the writing portion of this stream/socket should be shut
down. All currently blocked and future writes will return an error.
|
Both | Shut down both the reading and writing portions of this stream.
See Shutdown::Read and Shutdown::Write for more information.
|